@@ -21,35 +21,42 @@ pub struct RunRequest {
     pub bot: Option<CsmlBot>,
     pub bot_id: Option<String>,
     pub version_id: Option<String>,
-    pub fn_endpoint: Option<String>,
+    #[serde(alias = "fn_endpoint")]
+    pub apps_endpoint: Option<String>,
     pub event: CsmlRequest,
 }
 
 impl RunRequest {
     pub fn get_bot_opt(&self) -> Result<BotOpt, EngineError> {
         match self.clone() {
+            // Bot
             RunRequest {
                 bot: Some(csml_bot),
                 ..
             } => Ok(BotOpt::CsmlBot(csml_bot)),
+
+            // version id
             RunRequest {
                 version_id: Some(version_id),
                 bot_id: Some(bot_id),
-                fn_endpoint,
+                apps_endpoint,
                 ..
             } => Ok(BotOpt::Id {
                 version_id,
                 bot_id,
-                fn_endpoint,
+                apps_endpoint,
             }),
+
+            // bot id
             RunRequest {
                 bot_id: Some(bot_id),
-                fn_endpoint,
+                apps_endpoint,
                 ..
             } => Ok(BotOpt::BotId {
                 bot_id,
-                fn_endpoint,
+                apps_endpoint,
             }),
+
             _ => Err(EngineError::Format("Invalid bot_opt format".to_owned())),
         }
     }
@@ -63,12 +70,14 @@ pub enum BotOpt {
     Id {
         version_id: String,
         bot_id: String,
-        fn_endpoint: Option<String>,
+        #[serde(alias = "fn_endpoint")]
+        apps_endpoint: Option<String>,
     },
     #[serde(rename = "bot_id")]
     BotId {
         bot_id: String,
-        fn_endpoint: Option<String>,
+        #[serde(alias = "fn_endpoint")]
+        apps_endpoint: Option<String>,
     },
 }
 
@@ -78,24 +87,24 @@ impl BotOpt {
             BotOpt::CsmlBot(csml_bot) => csml_bot.to_owned(),
             BotOpt::BotId {
                 bot_id,
-                fn_endpoint,
+                apps_endpoint,
             } => {
                 let mut bot_version = db_connectors::bot::get_last_bot_version(&bot_id, db)
                     .unwrap()
                     .unwrap();
-                bot_version.bot.fn_endpoint = fn_endpoint.to_owned();
+                bot_version.bot.apps_endpoint = apps_endpoint.to_owned();
                 bot_version.bot
             }
             BotOpt::Id {
                 version_id,
                 bot_id,
-                fn_endpoint,
+                apps_endpoint,
             } => {
                 let mut bot_version =
                     db_connectors::bot::get_by_version_id(&version_id, &bot_id, db)
                         .unwrap()
                         .unwrap();
-                bot_version.bot.fn_endpoint = fn_endpoint.to_owned();
+                bot_version.bot.apps_endpoint = apps_endpoint.to_owned();
                 bot_version.bot
             }
         }
@@ -110,6 +119,7 @@ pub struct SerializeCsmlBot {
     pub native_components: Option<String>, // serde_json::Map<String, serde_json::Value>
     pub custom_components: Option<String>, // serde_json::Value
     pub default_flow: String,
+    pub no_interruption_delay: Option<i32>,
     pub env: Option<String>,
 }
 
@@ -139,6 +149,7 @@ impl CsmlBotBincode {
             native_components: self.native_components,
             custom_components: self.custom_components,
             default_flow: self.default_flow,
+            no_interruption_delay: None,
             env: None,
         }
     }
@@ -162,6 +173,7 @@ pub fn to_serializable_bot(bot: &CsmlBot) -> SerializeCsmlBot {
             }
         },
         default_flow: bot.default_flow.to_owned(),
+        no_interruption_delay: bot.no_interruption_delay,
         env: match &bot.env {
             Some(value) => encrypt_data(value).ok(),
             None => None,
@@ -174,7 +186,7 @@ impl SerializeCsmlBot {
         CsmlBot {
             id: self.id.to_owned(),
             name: self.name.to_owned(),
-            fn_endpoint: None,
+            apps_endpoint: None,
             flows: self.flows.to_owned(),
             native_components: {
                 match self.native_components.to_owned() {
@@ -196,7 +208,8 @@ impl SerializeCsmlBot {
             },
             default_flow: self.default_flow.to_owned(),
             bot_ast: None,
-            env: match self.custom_components.to_owned() {
+            no_interruption_delay: self.no_interruption_delay,
+            env: match self.env.to_owned() {
                 Some(value) => decrypt_data(value).ok(),
                 None => None,
             },
@@ -210,6 +223,7 @@ pub struct DynamoBot {
     pub name: String,
     pub custom_components: Option<String>,
     pub default_flow: String,
+    pub no_interruption_delay: Option<i32>,
     pub env: Option<String>,
 }
 
@@ -235,6 +249,7 @@ impl DynamoBotBincode {
             name: self.name,
             custom_components: self.custom_components,
             default_flow: self.default_flow,
+            no_interruption_delay: None,
             env: None,
         }
     }
@@ -249,6 +264,7 @@ pub fn to_dynamo_bot(csml_bot: &CsmlBot) -> DynamoBot {
             None => None,
         },
         default_flow: csml_bot.default_flow.to_owned(),
+        no_interruption_delay: csml_bot.no_interruption_delay,
         env: match &csml_bot.env {
             Some(value) => encrypt_data(value).ok(),
             None => None,
@@ -261,7 +277,7 @@ impl DynamoBot {
         CsmlBot {
             id: self.id.to_owned(),
             name: self.name.to_owned(),
-            fn_endpoint: None,
+            apps_endpoint: None,
             flows,
             native_components: None,
             custom_components: {
@@ -275,6 +291,7 @@ impl DynamoBot {
             },
             default_flow: self.default_flow.to_owned(),
             bot_ast: None,
+            no_interruption_delay: self.no_interruption_delay,
             env: match self.env.to_owned() {
                 Some(value) => decrypt_data(value).ok(),
                 None => None,
