@@ -5,6 +5,8 @@ use crate::db_connectors::{is_mongodb, mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
 
+use csml_interpreter::data::csml_logs::{LogLvl, CsmlLog, csml_logger};
+
 use crate::error_messages::ERROR_DB_SETUP;
 use crate::{Client, ConversationInfo, Database, DbConversation, EngineError};
 use crate::db_connectors::utils::*;
@@ -16,6 +18,25 @@ pub fn create_conversation(
     ttl: Option<chrono::Duration>,
     db: &mut Database,
 ) -> Result<String, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call create conversation flow_id: {}, step_id:{}", flow_id, step_id)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&client),
+            None,
+            None,
+            format!("db call create conversation flow_id: {}, step_id:{}", flow_id, step_id)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -48,6 +69,25 @@ pub fn create_conversation(
 }
 
 pub fn close_conversation(id: &str, client: &Client, db: &mut Database) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call close conversation conversation_id: {}", id)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&client),
+            None,
+            None,
+            format!("db call close conversation conversation_id: {}", id)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -70,6 +110,25 @@ pub fn close_conversation(id: &str, client: &Client, db: &mut Database) -> Resul
 }
 
 pub fn close_all_conversations(client: &Client, db: &mut Database) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call close all conversations")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&client),
+            None,
+            None,
+            format!("db call close all conversations, client: {:?}", client)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -95,6 +154,25 @@ pub fn get_latest_open(
     client: &Client,
     db: &mut Database,
 ) -> Result<Option<DbConversation>, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get latest open conversations")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&client),
+            None,
+            None,
+            format!("db call get latest open conversations")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -121,6 +199,25 @@ pub fn update_conversation(
     flow_id: Option<String>,
     step_id: Option<String>,
 ) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call update conversations flow_id {:?}, step_id {:?}", flow_id, step_id)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&data.client),
+            None,
+            None,
+            format!("db call update conversations flow_id {:?}, step_id {:?}", flow_id, step_id)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(&data.db)?;
@@ -165,6 +262,25 @@ pub fn get_client_conversations(
     limit: Option<i64>,
     pagination_key: Option<String>,
 ) -> Result<serde_json::Value, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get client conversations, limit: {:?}", limit)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&client),
+            None,
+            None,
+            format!("db call get client conversations limit: {:?}, pagination_key: {:?}", limit, pagination_key)
+        ),
+        LogLvl::Info
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
