@@ -4,15 +4,36 @@ use crate::db_connectors::{dynamodb as dynamodb_connector, is_dynamodb};
 use crate::db_connectors::{is_mongodb, mongodb as mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
+
+use csml_interpreter::data::csml_logs::{LogLvl, CsmlLog, csml_logger};
+
 use crate::error_messages::ERROR_DB_SETUP;
 use crate::{Client, ConversationInfo, Database, EngineError, Memory};
-use std::collections::HashMap;
 use crate::db_connectors::utils::*;
+use std::collections::HashMap;
 
 pub fn add_memories(
     data: &mut ConversationInfo,
     memories: &HashMap<String, Memory>,
 ) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call save memories {:?}", memories.keys())
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call save memories {:?}", memories.keys())
+        ),
+        LogLvl::Debug
+    );
 
     #[cfg(feature = "mongo")]
     if is_mongodb() {
@@ -42,6 +63,26 @@ pub fn create_client_memory(
     ttl: Option<chrono::Duration>,
     db: &mut Database
 ) -> Result<(), EngineError> {
+
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call save memory {:?}", key)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call save memory {:?} with value {:?}", key, value)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -68,6 +109,25 @@ pub fn create_client_memory(
 }
 
 pub fn internal_use_get_memories(client: &Client, db: &mut Database) -> Result<serde_json::Value, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get memories")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get memories")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -93,6 +153,25 @@ pub fn internal_use_get_memories(client: &Client, db: &mut Database) -> Result<s
  * Get client Memories
  */
  pub fn get_memories(client: &Client, db: &mut Database) -> Result<serde_json::Value, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get memories client")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get memories client")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -118,6 +197,25 @@ pub fn internal_use_get_memories(client: &Client, db: &mut Database) -> Result<s
  * Get client Memory
  */
  pub fn get_memory(client: &Client, key: &str, db: &mut Database) -> Result<serde_json::Value, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get memory {:?}", key)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get memory {:?}", key)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -141,6 +239,25 @@ pub fn internal_use_get_memories(client: &Client, db: &mut Database) -> Result<s
 
 
 pub fn delete_client_memory(client: &Client, key: &str, db: &mut Database) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call delete memory {:?}", key)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call delete memory {:?}", key)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -163,6 +280,25 @@ pub fn delete_client_memory(client: &Client, key: &str, db: &mut Database) -> Re
 }
 
 pub fn delete_client_memories(client: &Client, db: &mut Database) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call delete memories")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call delete memories")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
