@@ -4,17 +4,37 @@ use crate::db_connectors::{dynamodb as dynamodb_connector, is_dynamodb};
 use crate::db_connectors::{is_mongodb, mongodb as mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
+
+use csml_interpreter::data::csml_logs::{LogLvl, CsmlLog, csml_logger};
 use crate::error_messages::ERROR_DB_SETUP;
 use crate::{Database, ConversationInfo, EngineError, Client};
 use crate::db_connectors::utils::*;
 
-
 pub fn add_messages_bulk(
     data: &mut ConversationInfo,
     msgs: Vec<serde_json::Value>,
     interaction_order: i32,
     direction: &str,
 ) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call save messages {:?}", msgs)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&data.client),
+            None,
+            None,
+            format!("db call save messages {:?}", msgs)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let expires_at = get_expires_at_for_mongodb(data.ttl);
@@ -63,6 +83,25 @@ pub fn get_client_messages(
     limit: Option<i64>,
     pagination_key: Option<String>,
 ) -> Result<serde_json::Value, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get messages")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get messages")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
