@@ -4,6 +4,8 @@ use crate::db_connectors::{dynamodb as dynamodb_connector, is_dynamodb};
 use crate::db_connectors::{is_mongodb, mongodb as mongodb_connector};
 #[cfg(feature = "postgresql")]
 use crate::db_connectors::{is_postgresql, postgresql_connector};
+
+use csml_interpreter::data::csml_logs::{LogLvl, CsmlLog, csml_logger};
 use crate::error_messages::ERROR_DB_SETUP;
 use crate::{Database, EngineError};
 use crate::db_connectors::utils::*;
@@ -12,25 +14,44 @@ use csml_interpreter::data::Client;
 pub fn delete_state_key(
     client: &Client,
     _type: &str,
-    _key: &str,
+    key: &str,
     db: &mut Database,
 ) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call delete state key: {:?}, type: {:?}", key, _type)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call delete state key: {:?}, type: {:?}", key, _type)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
-        return mongodb_connector::state::delete_state_key(client, _type, _key, db);
+        return mongodb_connector::state::delete_state_key(client, _type, key, db);
     }
 
     #[cfg(feature = "dynamo")]
     if is_dynamodb() {
         let db = dynamodb_connector::get_db(db)?;
-        return dynamodb_connector::state::delete_state_key(client, _type, _key, db);
+        return dynamodb_connector::state::delete_state_key(client, _type, key, db);
     }
 
     #[cfg(feature = "postgresql")]
     if is_postgresql() {
         let db = postgresql_connector::get_db(db)?;
-        return postgresql_connector::state::delete_state_key(client, _type, _key, db);
+        return postgresql_connector::state::delete_state_key(client, _type, key, db);
     }
 
     Err(EngineError::Manager(ERROR_DB_SETUP.to_owned()))
@@ -42,6 +63,25 @@ pub fn get_state_key(
     _key: &str,
     db: &mut Database,
 ) -> Result<Option<serde_json::Value>, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get state key: {:?}, type: {:?}", _key, _type)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get state key: {:?}, type: {:?}", _key, _type)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -67,6 +107,25 @@ pub fn get_current_state(
     client: &Client,
     db: &mut Database,
 ) -> Result<Option<serde_json::Value>, EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call get current state")
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(client),
+            None,
+            None,
+            format!("db call get current state")
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(db)?;
@@ -95,6 +154,25 @@ pub fn set_state_items(
     ttl: Option<chrono::Duration>,
     _db: &mut Database,
 ) -> Result<(), EngineError> {
+    csml_logger(
+        CsmlLog::new(
+            None,
+            None,
+            None,
+            format!("db call set state type: {:?}, keys and values {:?}", _type, _keys_values)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(_client),
+            None,
+            None,
+            format!("db call set state type: {:?}, keys and values {:?}", _type, _keys_values)
+        ),
+        LogLvl::Debug
+    );
+
     #[cfg(feature = "mongo")]
     if is_mongodb() {
         let db = mongodb_connector::get_db(_db)?;
