@@ -5,12 +5,12 @@ use crate::utils::*;
 use crate::{data::*, delete_client_memories};
 
 use csml_interpreter::{
-    data::{ast::ForgetMemory, csml_bot::CsmlBot, csml_flow::CsmlFlow, Event, Hold, MSG},
+    data::{csml_logs::*, ast::ForgetMemory, csml_bot::CsmlBot, csml_flow::CsmlFlow, Event, Hold, MSG},
     interpret,
 };
 use serde_json::{map::Map, Value};
 use std::collections::HashMap;
-use std::{env, sync::mpsc, thread, time::SystemTime};
+use std::{sync::mpsc, thread};
 
 /**
  * This is the CSML Engine action.
@@ -25,11 +25,27 @@ pub fn interpret_step(
     let mut current_flow: &CsmlFlow = get_flow_by_id(&data.context.flow, &bot.flows)?;
     let mut interaction_order = 0;
     let mut conversation_end = false;
-    // let mut interaction_success = true;
     let (sender, receiver) = mpsc::channel::<MSG>();
     let context = data.context.clone();
-    let interpret_step = SystemTime::now();
 
+    csml_logger(
+        CsmlLog::new(
+            None,
+            Some(data.context.flow.to_string()),
+            None,
+            format!("interpreter: start interpretations of bot {:?}", bot.id)
+        ),
+        LogLvl::Info
+    );
+    csml_logger(
+        CsmlLog::new(
+            Some(&data.client),
+            Some(data.context.flow.to_string()),
+            None,
+            format!("interpreter: start interpretations of bot {:?}, with ", bot.id)
+        ),
+        LogLvl::Debug
+    );
     let new_bot = bot.clone();
     thread::spawn(move || {
         interpret(new_bot, context, event, Some(sender));
@@ -59,9 +75,39 @@ pub fn interpret_step(
                 }
             },
             MSG::Message(msg) => {
+                csml_logger(
+                    CsmlLog::new(
+                        None,
+                        Some(data.context.flow.to_string()),
+                        None,
+                        format!("sending message")
+                    ),
+                    LogLvl::Info
+                );
+                csml_logger(
+                    CsmlLog::new(
+                        Some(&data.client),
+                        Some(data.context.flow.to_string()),
+                        None,
+                        format!("sending message {:?}", msg)
+                    ),
+                    LogLvl::Debug
+                );
+
                 send_msg_to_callback_url(data, vec![msg.clone()], interaction_order, false);
                 data.messages.push(msg);
             }
+            MSG::Log{flow, line, message, log_lvl} => {
+                csml_logger(
+                    CsmlLog::new(
+                        Some(&data.client),
+                        Some(flow),
+                        Some(line),
+                        message
+                    ),
+                    log_lvl
+                );
+            }
             MSG::Hold(Hold {
                 index,
                 step_vars,
@@ -77,6 +123,25 @@ pub fn interpret_step(
                     "previous": previous
                 });
 
+                csml_logger(
+                    CsmlLog::new(
+                        None,
+                        Some(data.context.flow.to_string()),
+                        None,
+                        format!("hold bot")
+                    ),
+                    LogLvl::Info
+                );
+                csml_logger(
+                    CsmlLog::new(
+                        Some(&data.client),
+                        Some(data.context.flow.to_string()),
+                        None,
+                        format!("hold bot, state_hold {:?}", state_hold)
+                    ),
+                    LogLvl::Debug
+                );
+
                 set_state_items(
                     &data.client,
                     "hold",
@@ -94,6 +159,15 @@ pub fn interpret_step(
             }
             MSG::Next { flow, step } => match (flow, step) {
                 (Some(flow), Some(step)) => {
+                    csml_logger(
+                        CsmlLog::new(
+                            Some(&data.client),
+                            None,
+                            None,
+                            format!("goto flow: {}, step: {} from: flow: {} step: {}", flow, step, data.context.flow, data.context.step)
+                        ),
+                        LogLvl::Debug
+                    );
                     update_current_context(data, &memories);
                     goto_flow(
                         data,
@@ -105,6 +179,15 @@ pub fn interpret_step(
                     )?
                 }
                 (Some(flow), None) => {
+                    csml_logger(
+                        CsmlLog::new(
+                            Some(&data.client),
+                            None,
+                            None,
+                            format!("goto flow: {}, step: start from: flow: {} step: {}", flow, data.context.flow, data.context.step)
+                        ),
+                        LogLvl::Debug
+                    );
                     update_current_context(data, &memories);
                     let step = "start".to_owned();
                     goto_flow(
@@ -117,11 +200,30 @@ pub fn interpret_step(
                     )?
                 }
                 (None, Some(step)) => {
+                    csml_logger(
+                        CsmlLog::new(
+                            Some(&data.client),
+                            None,
+                            None,
+                            format!("goto flow: {}, step: {} from: flow: {} step: {}", data.context.flow, step, data.context.flow, data.context.step)
+                        ),
+                        LogLvl::Debug
+                    );
                     if goto_step(data, &mut conversation_end, &mut interaction_order, step)? {
                         break;
                     }
                 }
                 (None, None) => {
+                    csml_logger(
+                        CsmlLog::new(
+                            Some(&data.client),
+                            Some(data.context.flow.to_string()),
+                            None,
+                            format!("goto end from: flow: {} step: {}", data.context.flow, data.context.step)
+                        ),
+                        LogLvl::Debug
+                    );
+
                     let step = "end".to_owned();
                     if goto_step(data, &mut conversation_end, &mut interaction_order, step)? {
                         break;
@@ -130,7 +232,15 @@ pub fn interpret_step(
             },
             MSG::Error(err_msg) => {
                 conversation_end = true;
-                // interaction_success = false;
+                csml_logger(
+                    CsmlLog::new(
+                        Some(&data.client),
+                        Some(data.context.flow.to_string()),
+                        None,
+                        format!("interpreter error: {:?}", err_msg)
+                    ),
+                    LogLvl::Error
+                );
 
                 send_msg_to_callback_url(data, vec![err_msg.clone()], interaction_order, true);
                 data.messages.push(err_msg);
@@ -139,19 +249,6 @@ pub fn interpret_step(
         }
     }
 
-    if let Ok(var) = env::var(DEBUG) {
-        if var == "true" {
-            let el = interpret_step.elapsed()?;
-            eprintln!(
-                "Total Time interpret step {} - {}.{}",
-                data.context.step,
-                el.as_secs(),
-                el.as_millis()
-            );
-        }
-    }
-
-    let now = SystemTime::now();
     // save in db
     let msgs: Vec<serde_json::Value> = data
         .messages
@@ -164,20 +261,6 @@ pub fn interpret_step(
     }
     add_memories(data, &memories)?;
 
-    if let Ok(var) = env::var(DEBUG) {
-        if var == "true" {
-            let el = now.elapsed()?;
-            eprintln!(
-                "Save message & memories bulk at the end of step - {}.{}",
-                el.as_secs(),
-                el.as_millis()
-            );
-        }
-    }
-
-    //TODO: log update
-    // update_interaction(data, interaction_success)?;
-
     Ok(messages_formater(
         data,
         data.messages.clone(),
@@ -197,9 +280,6 @@ fn goto_flow<'a>(
     nextflow: String,
     nextstep: String,
 ) -> Result<(), EngineError> {
-    // TODO: add in logs
-    // create_node(data, Some(nextflow.clone()), Some(nextstep.clone()))?;
-
     *current_flow = get_flow_by_id(&nextflow, &bot.flows)?;
     data.context.flow = nextflow;
     data.context.step = nextstep;
@@ -211,8 +291,6 @@ fn goto_flow<'a>(
     )?;
 
     *interaction_order += 1;
-    // TODO: add in logs
-    // update_interaction(data, false)?;
 
     Ok(())
 }
@@ -226,9 +304,6 @@ fn goto_step<'a>(
     interaction_order: &mut i32,
     nextstep: String,
 ) -> Result<bool, EngineError> {
-    // TODO: add in logs
-    // create_node(data, None, Some(nextstep.clone()))?;
-
     if nextstep == "end" {
         *conversation_end = true;
 
