@@ -1,5 +1,5 @@
 use crate::{
-    data::{ConversationInfo, Database, EngineError, FlowTrigger, DEBUG},
+    data::{ConversationInfo, Database, EngineError, FlowTrigger},
     db_connectors::state::delete_state_key,
     send::send_to_callback_url,
     CsmlBot, CsmlFlow,
@@ -7,7 +7,7 @@ use crate::{
 
 use chrono::{prelude::Utc, SecondsFormat};
 use csml_interpreter::{
-    data::{ast::Flow, Client, Context, Event, Interval, Memory, Message},
+    data::{csml_logs::*, ast::Flow, Client, Context, Event, Interval, Memory, Message},
     error_format::{ERROR_KEY_ALPHANUMERIC, ERROR_NUMBER_AS_KEY, ERROR_SIZE_IDENT},
     get_step,
     interpreter::json_to_literal,
@@ -151,12 +151,15 @@ pub fn send_msg_to_callback_url(
 ) {
     let messages = messages_formater(data, msg, interaction_order, end);
 
-    match env::var(DEBUG) {
-        Ok(ref var) if var == "true" => {
-            println!("conversation_end => {}", messages["conversation_end"]);
-        }
-        _ => (),
-    };
+    csml_logger(
+        CsmlLog::new(
+            Some(&data.client),
+            Some(data.context.flow.to_string()),
+            None,
+            format!("conversation_end: {:?}", messages["conversation_end"])
+        ),
+        LogLvl::Debug
+    );
 
     send_to_callback_url(data, serde_json::json!(messages))
 }
@@ -367,19 +370,28 @@ pub fn clean_hold_and_restart(data: &mut ConversationInfo) -> Result<(), EngineE
     return Ok(());
 }
 
-#[cfg(feature = "dynamo")]
-pub fn init_logger() {
-    if let Ok(debug) = env::var("DEBUG") {
-        // RUST_LOG=rusoto
-        // hyper=debug
-        if &debug == "true" {
-            env::set_var("RUST_LOG", "rusoto");
-            env::set_var("hyper", "debug");
+// pub fn init_logger() {
+//     let env = env_logger::Env::default()
+//     .filter_or("CSML_LOG_LEVEL", "error");
 
-            let _ = env_logger::try_init();
-        }
-    };
-}
+//     let _ = env_logger::Builder::from_env(env)
+//     .format(|buf, record| {
+//         let style = buf.default_level_style(record.level());
+
+//         let timestamp = buf.timestamp_millis();
+//         let path = record.target();
+
+//         writeln!(
+//             buf,
+//             "{} {} {} {}",
+//             style.value(record.level()),
+//             timestamp,
+//             path,
+//             record.args()
+//         )
+//     })
+//     .try_init();
+// }
 
 pub fn get_ttl_duration_value(event: Option<&Event>) -> Option<chrono::Duration> {
 
